import logging
from os import environ


class DeprovConfig(object):
    def __init__(self):
        self.batch_size = self.get_int_environ("BATCH_SIZE", 10)
        self.link_batch_size = self.get_int_environ("LINK_BATCH_SIZE", 10000)
        self.dry_run = self.get_bool_environ("DRY_RUN", True)
        self.log_level = self.get_environ("LOG_LEVEL", "INFO")
        self.verbose = self.get_bool_environ("VERBOSE", False)
        self.aws_logging = self.get_bool_environ("AWS_LOGGER", True)
        self.pool_size = self.get_int_environ("POOL_SIZE", 20)
        self.continuous_mode = self.get_bool_environ("CONTINUOUS_MODE", False)
        self.rerun_delay_min = self.get_int_environ("RERUN_DELAY_MIN", 60)
        self.s3_bucket_name = self.get_environ("permanent_storage_bucket", "")

    @staticmethod
    def get_environ(label: str, default: str) -> str:
        return environ.get(label) or default

    @staticmethod
    def get_int_environ(label: str, default: int) -> int:
        return int(environ.get(label) or default)

    @staticmethod
    def get_bool_environ(label: str, default: bool) -> bool:
        return str(environ.get(label) or default).lower() == 'true'

    def vlog(self, message):
        if self.verbose:
            logging.info(message)

    def log(self):
        logging.info(
            F'''
-- CONFIG --
Batch Size:      {self.batch_size:,}
Link Batch Size: {self.link_batch_size:,}
Dry Run:         {self.dry_run}
Pool Size:       {self.pool_size:,}
Continuous Mode: {self.continuous_mode}
Rerun Delay (m): {self.rerun_delay_min}
Log Level:       {self.log_level}'''
        )


config = DeprovConfig()
