import datetime
import functools
import logging


def timed_sql_operation(func):
    @functools.wraps(func)
    def wrapper(*args, **kwargs):
        start_time = datetime.datetime.now()
        result = func(*args, **kwargs)
        duration = datetime.datetime.now() - start_time
        if isinstance(result, int):
            logging.info(f'-- Items: {result:,}', extra={'duration': str(duration)})
        else:
            logging.info(f'-- {result or "Operation completed."}', extra={'duration': str(duration)})
        return result
    return wrapper
